
-- Local constants
-- This _has_ to be set to 1
local GATE_OPENED = 1
-- This has to be != from GATE_OPENED and is coded on 4 bits
local GATE_CLOSED = 0

-- Local Functions
local on_gate_punched = function(pos, node, puncher)
	if (node.name ~= 'gates:gate_closed')
		and (node.name ~= 'gates:gate_opened') then
		return
	end
	local state = node.param2

	-- Switch the gate state when hit
	if state == GATE_OPENED then
		node.name = 'gates:gate_closed'
		node.param2 = GATE_CLOSED
	elseif state == GATE_CLOSED then
		node.name = 'gates:gate_opened'
		node.param2 = GATE_OPENED
	else
		print('Uninitialized node: ' .. state)
	end

	minetest.env:add_node(pos, {
		name = node.name,
		param2 = node.param2,
	})
end

local on_gate_placed = function(pos, node, placer)
	if node.name ~= 'gates:gate_opened' then
		return
	end

	minetest.env:add_node(pos, {
		name = node.name,
		param2 = GATE_OPENED,
	})
end

-- Nodes
-- As long as param2 is set to 1 for open gates, it doesn't matter to
-- use drawtype = 'signlike'
minetest.register_node('gates:gate_opened', {
	drawtype = 'plantlike',
	visual_scale = 1.5,
	tile_images = {'gate_open.png'},
	sunlight_propagates = true,
	paramtype = 'light',
	walkable = false,
	material = minetest.digprop_constanttime(1.0),
	drop = "gates:gate_closed",
})

minetest.register_node('gates:gate_closed', {
	tile_images = {'gate_top.png','gate_top.png','gate.png'},
	sunlight_propagates = true,
	paramtype = 'light',
	walkable = true,
	material = minetest.digprop_constanttime(1.0),
	drop = "gates:gate_closed",
})

-- Crafts
minetest.register_craft({
	output = 'NodeItem "gates:gate_closed" 2',
	recipe = {
		{"default:stick", "default:wood", "default:stick"},
		{"default:stick", "default:wood", "default:stick"},
	},
})

-- Change the gate state
minetest.register_on_punchnode(on_gate_punched)
-- Reset param2 for open gates
minetest.register_on_placenode(on_gate_placed)


print("[Gates] Loaded!")
